@@ -69,10 +69,16 @@ class SpectacularAPIView(APIView):
     def _get_schema_response(self, request):
         # version specified as parameter to the view always takes precedence. after
         # that we try to source version through the schema view's own versioning_class.
-        version = self.api_version or request.version
+        version = self.api_version or request.version or self._get_version_parameter(request)
         generator = self.generator_class(urlconf=self.urlconf, api_version=version)
         return Response(generator.get_schema(request=request, public=self.serve_public))
 
+    def _get_version_parameter(self, request):
+        version = request.GET.get('version')
+        if not api_settings.ALLOWED_VERSIONS or version in api_settings.ALLOWED_VERSIONS:
+            return version
+        return None
+
 
 class SpectacularYAMLAPIView(SpectacularAPIView):
     renderer_classes = [OpenApiYamlRenderer, OpenApiYamlRenderer2]
